@@ -46,6 +46,8 @@ private:
     wxStaticText * M_pos;
     wxStaticText * M_vel;
     wxStaticText * M_polar;
+    wxStaticText * M_last_move;
+    wxStaticText * M_last_polar;
 
     //! not used
     BallPanel();
