@@ -30,7 +30,7 @@
 /////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 // for compliers supporting precompling
@@ -45,17 +45,20 @@
 #include <wx/wx.h>
 #endif
 
-#include <iostream>
-#include <cassert>
-#include <algorithm>
+#include "feditor_canvas.h"
 
-#include "id.h"
-#include "app_config.h"
-#include "gdi_config.h"
 #include "feditor_frame.h"
 #include "feditor_data.h"
+#include "fedit_config.h"
+#include "id.h"
 
-#include "feditor_canvas.h"
+#include <rcsc/formation/formation_dt.h>
+
+#include <rcsc/geom/triangle_2d.h>
+
+#include <algorithm>
+#include <iostream>
+#include <cassert>
 
 /*-------------------------------------------------------------------*/
 /*!
@@ -67,19 +70,19 @@ FEditorCanvas::FEditorCanvas( FEditorFrame * parent )
     , M_parent( parent )
     , M_scale( 1.0 )
     , M_center( 0, 0 )
-    , M_field_brush( GDIConfig::FIELD_COLOR, wxSOLID )
-    , M_field_dark_brush( GDIConfig::FIELD_DARK_COLOR, wxSOLID )
-    , M_line_pen( GDIConfig::LINE_COLOR, 1, wxSOLID )
+    , M_field_brush(  wxColor( 31, 160, 31 ), wxSOLID )
+    , M_field_dark_brush( wxColor( 15, 143, 15 ), wxSOLID )
+    , M_line_pen( wxColor( 255, 255, 255 ), 1, wxSOLID )
     , M_triangle_pen( wxColor( 255, 127, 0 ), 1, wxSOLID )
     , M_triangle_font( 10, wxDEFAULT, wxNORMAL, wxNORMAL, false, wxT( "" ), wxFONTENCODING_ISO8859_1 ) //wxFONTENCODING_SYSTEM )
     , M_area_pen( wxColor( 127, 127, 127 ), 1, wxSOLID )
-    , M_ball_pen( GDIConfig::BALL_PEN_COLOR, 1, wxSOLID )
-    , M_ball_brush( GDIConfig::BALL_COLOR, wxSOLID )
-    , M_player_pen( GDIConfig::PLAYER_PEN_COLOR, 1, wxSOLID )
+    , M_ball_pen( wxColor( 255, 255, 255 ), 1, wxSOLID )
+    , M_ball_brush( wxColor( 255, 255, 255 ), wxSOLID )
+    , M_player_pen( wxColor( 0, 0, 0 ), 1, wxSOLID )
     , M_select_pen( *wxWHITE, 2, wxSOLID )
-    , M_left_team_brush( GDIConfig::LEFT_TEAM_COLOR, wxSOLID )
-    , M_right_team_brush( GDIConfig::RIGHT_TEAM_COLOR, wxSOLID )
-    , M_mirror_brush( GDIConfig::DEBUG_TEAMMATE_COLOR, wxSOLID )
+    , M_left_team_brush( wxColor( 255, 215, 0 ), wxSOLID )
+    , M_right_team_brush( wxColor( 240, 20, 20 ), wxSOLID )
+    , M_mirror_brush( wxColor( 0, 255, 95 ), wxSOLID )
     , M_player_font( 10, wxDEFAULT, wxNORMAL, wxNORMAL, false, wxT( "" ), wxFONTENCODING_ISO8859_1 ) //wxFONTENCODING_SYSTEM )
 {
     assert( parent );
@@ -154,10 +157,10 @@ FEditorCanvas::updateSize()
     M_center.x = this->GetClientSize().x / 2;
     M_center.y = this->GetClientSize().y / 2;
 
-    const double pitch_l = ( AppConfig::PITCH_LENGTH
-                             + AppConfig::PITCH_MARGIN * 2.0 );
-    const double pitch_w = ( AppConfig::PITCH_WIDTH
-                             + AppConfig::PITCH_MARGIN * 2.0 );
+    const double pitch_l = ( FEditConfig::PITCH_LENGTH
+                             + FEditConfig::PITCH_MARGIN * 2.0 );
+    const double pitch_w = ( FEditConfig::PITCH_WIDTH
+                             + FEditConfig::PITCH_MARGIN * 2.0 );
 
     M_scale = this->GetClientSize().x / pitch_l;
     if ( pitch_w * M_scale > this->GetSize().y )
@@ -240,10 +243,10 @@ FEditorCanvas::drawField( wxDC & dc )
     drawContainedArea( dc );
 
     // set screen coordinates of field
-    const wxCoord left_x   = getScreenX( - AppConfig::PITCH_LENGTH * 0.5 );
-    const wxCoord right_x  = getScreenX( + AppConfig::PITCH_LENGTH * 0.5 );
-    const wxCoord top_y    = getScreenY( - AppConfig::PITCH_WIDTH * 0.5 );
-    const wxCoord bottom_y = getScreenY( + AppConfig::PITCH_WIDTH * 0.5 );
+    const wxCoord left_x   = getScreenX( - FEditConfig::PITCH_LENGTH * 0.5 );
+    const wxCoord right_x  = getScreenX( + FEditConfig::PITCH_LENGTH * 0.5 );
+    const wxCoord top_y    = getScreenY( - FEditConfig::PITCH_WIDTH * 0.5 );
+    const wxCoord bottom_y = getScreenY( + FEditConfig::PITCH_WIDTH * 0.5 );
 
     // fill bottom side
     //dc.SetPen( *wxTRANSPARENT_PEN );
@@ -263,36 +266,36 @@ FEditorCanvas::drawField( wxDC & dc )
     // center line
     dc.DrawLine( M_center.x, top_y, M_center.x, bottom_y );
     // center circle
-    const wxCoord center_radius = scale( AppConfig::CENTER_CIRCLE_R );
+    const wxCoord center_radius = scale( FEditConfig::CENTER_CIRCLE_R );
     dc.DrawCircle( M_center, center_radius );
     // draw penalty area box
-    const wxCoord pen_top_y    = getScreenY( - AppConfig::PENALTY_AREA_WIDTH / 2 );
-    const wxCoord pen_bottom_y = getScreenY( + AppConfig::PENALTY_AREA_WIDTH / 2 );
+    const wxCoord pen_top_y    = getScreenY( - FEditConfig::PENALTY_AREA_WIDTH / 2 );
+    const wxCoord pen_bottom_y = getScreenY( + FEditConfig::PENALTY_AREA_WIDTH / 2 );
     // left penalty box
-    wxCoord pen_x = getScreenX( -( AppConfig::PITCH_LENGTH*0.5
-                                   - AppConfig::PENALTY_AREA_LENGTH ) );
+    wxCoord pen_x = getScreenX( -( FEditConfig::PITCH_LENGTH*0.5
+                                   - FEditConfig::PENALTY_AREA_LENGTH ) );
     dc.DrawLine( left_x, pen_top_y, pen_x, pen_top_y );
     dc.DrawLine( pen_x, pen_top_y, pen_x, pen_bottom_y );
     dc.DrawLine( pen_x, pen_bottom_y, left_x, pen_bottom_y );
     // right penalty box
-    pen_x = getScreenX( +( AppConfig::PITCH_LENGTH*0.5
-                           - AppConfig::PENALTY_AREA_LENGTH ) );
+    pen_x = getScreenX( +( FEditConfig::PITCH_LENGTH*0.5
+                           - FEditConfig::PENALTY_AREA_LENGTH ) );
     dc.DrawLine( right_x, pen_top_y, pen_x, pen_top_y );
     dc.DrawLine( pen_x, pen_top_y, pen_x, pen_bottom_y );
     dc.DrawLine( pen_x, pen_bottom_y, right_x, pen_bottom_y );
     // draw goal area box
-    const wxCoord goal_area_y_abs = scale( AppConfig::GOAL_AREA_WIDTH*0.5 );
+    const wxCoord goal_area_y_abs = scale( FEditConfig::GOAL_AREA_WIDTH*0.5 );
     const wxCoord goal_area_top_y = M_center.y - goal_area_y_abs;
     const wxCoord goal_area_bottom_y = M_center.y + goal_area_y_abs;
     // left goal area
-    wxCoord goal_area_x = getScreenX( - AppConfig::PITCH_LENGTH*0.5
-                                      + AppConfig::GOAL_AREA_LENGTH );
+    wxCoord goal_area_x = getScreenX( - FEditConfig::PITCH_LENGTH*0.5
+                                      + FEditConfig::GOAL_AREA_LENGTH );
     dc.DrawLine( left_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     dc.DrawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     dc.DrawLine( goal_area_x, goal_area_bottom_y, left_x, goal_area_bottom_y );
     // right goal area
-    goal_area_x = getScreenX( AppConfig::PITCH_LENGTH*0.5
-                              - AppConfig::GOAL_AREA_LENGTH );
+    goal_area_x = getScreenX( FEditConfig::PITCH_LENGTH*0.5
+                              - FEditConfig::GOAL_AREA_LENGTH );
     dc.DrawLine( right_x, goal_area_top_y, goal_area_x, goal_area_top_y );
     dc.DrawLine( goal_area_x, goal_area_top_y, goal_area_x, goal_area_bottom_y );
     dc.DrawLine( goal_area_x, goal_area_bottom_y, right_x, goal_area_bottom_y );
@@ -301,15 +304,15 @@ FEditorCanvas::drawField( wxDC & dc )
     // draw goal boxes
     dc.SetPen( *wxBLACK_PEN );
     dc.SetBrush( *wxBLACK_BRUSH );
-    const wxCoord goal_top_y = getScreenY( - AppConfig::GOAL_WIDTH*0.5 );
-    const wxCoord goal_size_x = scale( AppConfig::GOAL_DEPTH );
-    const wxCoord goal_size_y = scale( AppConfig::GOAL_WIDTH );
+    const wxCoord goal_top_y = getScreenY( - FEditConfig::GOAL_WIDTH*0.5 );
+    const wxCoord goal_size_x = scale( FEditConfig::GOAL_DEPTH );
+    const wxCoord goal_size_y = scale( FEditConfig::GOAL_WIDTH );
     // left goal
-    dc.DrawRectangle( getScreenX( - AppConfig::PITCH_LENGTH*0.5
-                                  - AppConfig::GOAL_DEPTH ),
+    dc.DrawRectangle( getScreenX( - FEditConfig::PITCH_LENGTH*0.5
+                                  - FEditConfig::GOAL_DEPTH ),
                       goal_top_y, goal_size_x, goal_size_y );
     // right goal
-    dc.DrawRectangle( getScreenX( AppConfig::PITCH_LENGTH*0.5 ) + 1,
+    dc.DrawRectangle( getScreenX( FEditConfig::PITCH_LENGTH*0.5 ) + 1,
                       goal_top_y, goal_size_x + 1, goal_size_y );
 }
 
@@ -326,13 +329,13 @@ FEditorCanvas::drawContainedArea( wxDC & dc )
         return ;
     }
 
-    boost::shared_ptr< const Formation > f = ptr->formation();
+    boost::shared_ptr< const rcsc::Formation > f = ptr->formation();
     if ( ! f )
     {
         return;
     }
 
-    if ( f->getMethodName() != "Delaunay" )
+    if ( f->methodName() != rcsc::FormationDT::name() )
     {
         return;
     }
@@ -358,6 +361,18 @@ FEditorCanvas::drawContainedArea( wxDC & dc )
         };
 
         dc.DrawPolygon( 3, vertices );
+
+        // draw center point
+        rcsc::Vector2D center
+            = rcsc::Triangle2D::centroid( tri->vertex( 0 )->pos(),
+                                          tri->vertex( 1 )->pos(),
+                                          tri->vertex( 2 )->pos() );
+
+        dc.SetPen( *wxCYAN_PEN );
+        dc.SetBrush( *wxCYAN_BRUSH );
+        dc.DrawRectangle( getScreenX( center.x ) - 1,
+                          getScreenY( center.y ) - 1,
+                          3, 3 );
     }
 }
 
@@ -374,32 +389,49 @@ FEditorCanvas::drawTrainingData( wxDC & dc )
         return;
     }
 
-    boost::shared_ptr< const Formation > f = ptr->formation();
+    boost::shared_ptr< const rcsc::Formation > f = ptr->formation();
     if ( ! f )
     {
         return;
     }
 
-    if (  f->getMethodName() != "Delaunay" )
+    // if method type is not a FormationDelaunayTriangulation
+    // only sample ball points are drawn
+    if ( f->methodName() != rcsc::FormationDT::name() )
     {
-        dc.SetPen( M_triangle_pen );
+        dc.SetPen( *wxRED_PEN ); //M_triangle_pen );
         dc.SetBrush( *wxTRANSPARENT_BRUSH );
+        dc.SetFont( M_player_font );
+        dc.SetTextForeground( *wxRED );
+        dc.SetBackgroundMode( wxTRANSPARENT );
 
-        const std::list< Formation::Snapshot >::const_iterator train_end
+        const int r = scale( 0.5 );
+
+        int count = 0;
+        const std::list< rcsc::Formation::Snapshot >::const_iterator train_end
             = ptr->getTrainingData().end();
-        for ( std::list< Formation::Snapshot >::const_iterator train_it
+        for ( std::list< rcsc::Formation::Snapshot >::const_iterator train_it
                   = ptr->getTrainingData().begin();
               train_it != train_end;
               ++train_it )
         {
-            dc.DrawCircle( getScreenX( train_it->ball_.x ),
-                           getScreenY( train_it->ball_.y ),
-                           scale( 0.8 ) );
+            int x = getScreenX( train_it->ball_.x );
+            int y = getScreenY( train_it->ball_.y );
+            //dc.DrawCircle( x, y, r );
+            dc.DrawLine( x - r, y - r,
+                         x + r, y + r );
+            dc.DrawLine( x - r, y + r,
+                         x + r, y - r );
+            wxString str;
+            str.sprintf( wxT( "%2d" ), ++count );
+            dc.DrawText( str,
+                         x + r, y - r );
         }
 
         return;
     }
 
+    // draw delaunay triangulation
 
     if ( ptr->getTriangulation().vertices().size() < 3 )
     {
@@ -430,9 +462,9 @@ FEditorCanvas::drawTrainingData( wxDC & dc )
 
     const int radius = scale( 0.7 );
     int count = 0;
-    const std::list< Formation::Snapshot >::const_iterator v_end
+    const std::list< rcsc::Formation::Snapshot >::const_iterator v_end
         = ptr->getTrainingData().end();
-    for ( std::list< Formation::Snapshot >::const_iterator it
+    for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
               = ptr->getTrainingData().begin();
           it != v_end;
           ++it )
@@ -459,7 +491,7 @@ FEditorCanvas::drawPlayers( wxDC & dc )
         return;
     }
 
-    boost::shared_ptr< const Formation > f = ptr->formation();
+    boost::shared_ptr< const rcsc::Formation > f = ptr->formation();
     if ( ! f )
     {
         return;
