@@ -56,22 +56,20 @@
 #include <algorithm>
 
 #include <rcsc/math_util.h>
+#include <rcsc/formation/formation_bpn.h>
+#include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_sbsp.h>
 
 #include "id.h"
-#include "app_config.h"
-#include "gdi_config.h"
+#include "fedit_config.h"
 
 #include "feditor_frame.h"
 #include "feditor_canvas.h"
 #include "feditor_dialog.h"
 
-#include "formation_delaunay.h"
-#include "formation_bpn.h"
-#include "formation_sbsp.h"
-
 #include "feditor_data.h"
 
-const int FEditorData::MAX_TRAINING_DATA_SIZE = 64;
+const int FEditorData::MAX_TRAINING_DATA_SIZE = 128;
 
 
 /*-------------------------------------------------------------------*/
@@ -113,22 +111,22 @@ FEditorData::~FEditorData()
 /*!
 
 */
-boost::shared_ptr< Formation >
+boost::shared_ptr< rcsc::Formation >
 FEditorData::create_formation( const std::string & type_name )
 {
-    boost::shared_ptr< Formation > f;
+    boost::shared_ptr< rcsc::Formation > f;
 
-    if ( type_name == FormationDelaunay::name() )
+    if ( type_name == rcsc::FormationDT::name() )
     {
-        f = boost::shared_ptr< Formation >( new FormationDelaunay );
+        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationDT );
     }
-    else if ( type_name == FormationBPN::name() )
+    else if ( type_name == rcsc::FormationBPN::name() )
     {
-        f = boost::shared_ptr< Formation >( new FormationBPN );
+        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationBPN );
     }
-    else if ( type_name == FormationSBSP::name() )
+    else if ( type_name == rcsc::FormationSBSP::name() )
     {
-        f = boost::shared_ptr< Formation >( new FormationSBSP );
+        f = boost::shared_ptr< rcsc::Formation >( new rcsc::FormationSBSP );
     }
     else
     {
@@ -164,10 +162,10 @@ FEditorData::init()
     M_ball_draggable = true;
     M_player_auto_move = true;
 
-    M_triangulation.init( rcsc::Rect2D( - AppConfig::PITCH_LENGTH * 0.5,
-                                        - AppConfig::PITCH_WIDTH * 0.5,
-                                        AppConfig::PITCH_LENGTH,
-                                        AppConfig::PITCH_WIDTH ) );
+    M_triangulation.init( rcsc::Rect2D( - FEditConfig::PITCH_LENGTH * 0.5,
+                                        - FEditConfig::PITCH_WIDTH * 0.5,
+                                        FEditConfig::PITCH_LENGTH,
+                                        FEditConfig::PITCH_WIDTH ) );
     updateTriangulation();
 
     printMessageWithTime( "init" );
@@ -180,7 +178,7 @@ FEditorData::init()
 void
 FEditorData::printMessageWithTime( char * msg, ... )
 {
-    if ( AppConfig::instance().editorLogging() )
+    if ( FEditConfig::instance().logging() )
     {
         std::time_t t;
         std::time( &t );
@@ -236,7 +234,7 @@ FEditorData::createDefaultParam()
         return;
     }
 
-    Formation::Snapshot default_data = M_formation->createDefaultParam();
+    rcsc::Formation::Snapshot default_data = M_formation->createDefaultParam();
 
     M_train_data.push_back( default_data );
     M_frame->setTrainDataIndexMax( static_cast< int >( M_train_data.size() ) );
@@ -362,7 +360,7 @@ FEditorData::openTrainData( const std::string & filepath )
     std::string line_buf;
     while ( std::getline( fin, line_buf ) )
     {
-        Formation::Snapshot snap;
+        rcsc::Formation::Snapshot snap;
         std::istringstream istr( line_buf );
         istr >> snap.ball_.x >> snap.ball_.y;
         for ( int i = 0; i < 11; ++i )
@@ -397,6 +395,8 @@ FEditorData::openTrainData( const std::string & filepath )
 
         updateTriangulation();
         train();
+        M_modified = false;
+        M_train_data_changed = false;
         moveBallTo( 0.0, 0.0 );
         updatePlayerPosition();
     }
@@ -459,33 +459,34 @@ FEditorData::save()
         {
             std::sprintf( time_str, ".time-%ld", current );
         }
-        
+
         std::string backup_filepath = M_filepath + time_str;
         std::ifstream fin( M_filepath.c_str() );
-        std::ofstream backup( backup_filepath.c_str() );
-        if ( fin && backup )
+        std::ofstream fout( backup_filepath.c_str() );
+        if ( fin && fout )
         {
             std::istreambuf_iterator< char > in_itr( fin );
-            std::ostreambuf_iterator< char > out_itr( backup );
+            std::ostreambuf_iterator< char > out_itr( fout );
             std ::copy( in_itr, std::istreambuf_iterator< char >(),
                         out_itr );
 
             fin.close();
-            backup.close();
+            fout.close();
         }
     }
 
-
-    std::ofstream fout( M_filepath.c_str() );
-    if ( ! fout.is_open() )
+    bool success = false;
     {
+        std::ofstream fout( M_filepath.c_str() );
+        if ( ! fout.is_open() )
+        {
+            fout.close();
+            return false;
+        }
+        success = save( fout );
         fout.close();
-        return false;
     }
 
-    bool success = save( fout );
-    fout.close();
-
     printMessageWithTime( "save formation" );
     return success;
 }
@@ -611,7 +612,7 @@ FEditorData::saveTrainData()
         {
             std::sprintf( time_str, ".time-%ld", current );
         }
-        
+
         std::string backup_filepath = M_filepath_train + time_str;
         std::ifstream fin( M_filepath_train.c_str() );
         std::ofstream backup( backup_filepath.c_str() );
@@ -650,7 +651,7 @@ FEditorData::saveTrainData()
 bool
 FEditorData::saveTrainData( std::ostream & os )
 {
-    for ( std::list< Formation::Snapshot >::iterator it = M_train_data.begin();
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_train_data.begin();
           it != M_train_data.end();
           ++it )
     {
@@ -860,10 +861,10 @@ FEditorData::updatePlayerPosition()
 void
 FEditorData::updateTriangulation()
 {
-    rcsc::Rect2D pitch( - AppConfig::PITCH_LENGTH * 0.5,
-                        - AppConfig::PITCH_WIDTH * 0.5,
-                        AppConfig::PITCH_LENGTH,
-                        AppConfig::PITCH_WIDTH );
+    rcsc::Rect2D pitch( - FEditConfig::PITCH_LENGTH * 0.5,
+                        - FEditConfig::PITCH_WIDTH * 0.5,
+                        FEditConfig::PITCH_LENGTH,
+                        FEditConfig::PITCH_WIDTH );
     M_triangulation.init( pitch );
     /*
     M_triangulation.addVertex( 0.0, 0.0 );
@@ -872,9 +873,9 @@ FEditorData::updateTriangulation()
     M_triangulation.addVertex( pitch.bottomRight() );
     M_triangulation.addVertex( pitch.topRight() );
     */
-    const std::list< Formation::Snapshot >::const_iterator end
+    const std::list< rcsc::Formation::Snapshot >::const_iterator end
         = getTrainingData().end();
-    for ( std::list< Formation::Snapshot >::const_iterator it
+    for ( std::list< rcsc::Formation::Snapshot >::const_iterator it
               = getTrainingData().begin();
           it != end;
           ++it )
@@ -962,10 +963,10 @@ FEditorData::moveBallTo( const double & x,
                          const double & y )
 {
     rcsc::Vector2D pos( x, y );
-    pos.y = std::max( - AppConfig::PITCH_WIDTH * 0.5 - 2.0, pos.y );
-    pos.y = std::min( + AppConfig::PITCH_WIDTH * 0.5 + 2.0, pos.y );
-    pos.x = std::max( - AppConfig::PITCH_LENGTH * 0.5 - 2.0, pos.x );
-    pos.x = std::min( + AppConfig::PITCH_LENGTH * 0.5 + 2.0, pos.x );
+    pos.y = std::max( - FEditConfig::PITCH_WIDTH * 0.5 - 2.0, pos.y );
+    pos.y = std::min( + FEditConfig::PITCH_WIDTH * 0.5 + 2.0, pos.y );
+    pos.x = std::max( - FEditConfig::PITCH_LENGTH * 0.5 - 2.0, pos.x );
+    pos.x = std::min( + FEditConfig::PITCH_LENGTH * 0.5 + 2.0, pos.x );
 
     M_ball = pos;
     if ( pos.absY() < 1.0 )
@@ -1120,10 +1121,10 @@ FEditorData::setObjectDragPoint( double x,
         return;
     }
 
-    y = std::max( - AppConfig::PITCH_WIDTH * 0.5 - 2.0, y );
-    y = std::min( + AppConfig::PITCH_WIDTH * 0.5 + 2.0, y );
-    x = std::max( - AppConfig::PITCH_LENGTH * 0.5 - 2.0, x );
-    x = std::min( + AppConfig::PITCH_LENGTH * 0.5 + 2.0, x );
+    y = std::max( - FEditConfig::PITCH_WIDTH * 0.5 - 2.0, y );
+    y = std::min( + FEditConfig::PITCH_WIDTH * 0.5 + 2.0, y );
+    x = std::max( - FEditConfig::PITCH_LENGTH * 0.5 - 2.0, x );
+    x = std::min( + FEditConfig::PITCH_LENGTH * 0.5 + 2.0, x );
 
     switch ( M_select_type ) {
     case SELECT_OUR:
@@ -1256,7 +1257,7 @@ FEditorData::recordCurrentPosition()
         return;
     }
 
-    for ( std::list< Formation::Snapshot >::iterator it = M_train_data.begin();
+    for ( std::list< rcsc::Formation::Snapshot >::iterator it = M_train_data.begin();
           it != M_train_data.end();
           ++it )
     {
@@ -1274,7 +1275,7 @@ FEditorData::recordCurrentPosition()
     }
 
 
-    M_train_data.push_back( Formation::Snapshot( M_ball, M_our_players ) );
+    M_train_data.push_back( rcsc::Formation::Snapshot( M_ball, M_our_players ) );
     std::cerr << "Save positin. current data size = " << M_train_data.size()
               << std::endl;
 
@@ -1299,7 +1300,7 @@ FEditorData::focusTrainData( const int idx )
 {
     printMessageWithTime( "focusTrainData index=%d", idx );
 
-    std::list< Formation::Snapshot >::iterator it = M_train_data.begin();
+    std::list< rcsc::Formation::Snapshot >::iterator it = M_train_data.begin();
 
     int count = 1;
     while ( it != M_train_data.end() )
@@ -1332,13 +1333,13 @@ FEditorData::replaceTrainData( const int idx )
         return;
     }
 
-    std::list< Formation::Snapshot >::iterator it = M_train_data.begin();
+    std::list< rcsc::Formation::Snapshot >::iterator it = M_train_data.begin();
     int count = 1;
     while ( it != M_train_data.end() )
     {
         if ( idx == count )
         {
-            *it = Formation::Snapshot( M_ball, M_our_players );
+            *it = rcsc::Formation::Snapshot( M_ball, M_our_players );
             M_train_data_changed = true;
             break;
         }
@@ -1363,7 +1364,7 @@ FEditorData::deleteTrainData( const int idx )
         return;
     }
 
-    std::list< Formation::Snapshot >::iterator it = M_train_data.begin();
+    std::list< rcsc::Formation::Snapshot >::iterator it = M_train_data.begin();
     int count = 1;
     while ( it != M_train_data.end() )
     {
