@@ -48,6 +48,10 @@
 
 #include <iostream>
 
+#include <rcsc/formation/formation_bpn.h>
+#include <rcsc/formation/formation_dt.h>
+#include <rcsc/formation/formation_sbsp.h>
+
 #include "xpm/chase.xpm"
 #include "xpm/delete.xpm"
 #include "xpm/hand.xpm"
@@ -57,15 +61,11 @@
 #include "xpm/save.xpm"
 
 #include "id.h"
-#include "app_config.h"
+#include "fedit_config.h"
 #include "feditor_canvas.h"
 #include "feditor_data.h"
 #include "feditor_dialog.h"
 
-#include "formation_delaunay.h"
-#include "formation_bpn.h"
-#include "formation_sbsp.h"
-
 #include "feditor_frame.h"
 
 #if defined(__WXGTK__) || defined(__WXX11__) || defined(__WXMOTIF__) || defined(__WXMAC__)
@@ -87,14 +87,25 @@ FEditorFrame::FEditorFrame()
 {
     // set minimal window size
     this->SetSizeHints( 280, 220 );
-    this->SetSize( AppConfig::instance().framePosX(),
-                   AppConfig::instance().framePosY(),
-                   AppConfig::instance().frameWidth(),
-                   AppConfig::instance().frameHeight() );
+    this->SetSize( FEditConfig::instance().framePosX(),
+                   FEditConfig::instance().framePosY(),
+                   FEditConfig::instance().frameWidth(),
+                   FEditConfig::instance().frameHeight() );
 
     createWindows();
     connectEvents();
 
+
+    if ( FEditConfig::instance().maximize() )
+    {
+        this->Maximize( true );
+    }
+
+    if ( FEditConfig::instance().fullScreen() )
+    {
+        this->ShowFullScreen( true );
+    }
+
     SetIcon( wxICON( soccerwindow2_nostr ) );
 }
 
@@ -403,9 +414,9 @@ FEditorFrame::handleMenuNew( wxCommandEvent & WXUNUSED( event ) )
     }
 
     // select formation training type
-    wxString choices[3] = { wxString( FormationDelaunay::name().c_str(), *wxConvCurrent ),
-                            wxString( FormationBPN::name().c_str(), *wxConvCurrent ) //,
-                            //wxString( FormationSBSP::name().c_str(), *wxConvCurrent )
+    wxString choices[3] = { wxString( rcsc::FormationDT::name().c_str(), *wxConvCurrent ),
+                            wxString( rcsc::FormationBPN::name().c_str(), *wxConvCurrent ) //,
+                            //wxString( rcsc::FormationSBSP::name().c_str(), *wxConvCurrent )
     };
 
     wxSingleChoiceDialog dlg( this,
@@ -678,6 +689,7 @@ FEditorFrame::handleDeleteTrainData( wxCommandEvent & WXUNUSED( event ) )
     if ( M_editor_data )
     {
         M_editor_data->deleteTrainData( M_train_data_index->GetValue() );
+        M_editor_data->train();
     }
 }
 
