@@ -355,6 +355,32 @@ FieldCanvas::drawMouseMeasure( wxDC & mem_dc )
     rcsc::Vector2D start_real = M_data.config().getFieldPoint( start_point );
     rcsc::Vector2D end_real = M_data.config().getFieldPoint( end_point );
 
+    // ball travel marks
+    {
+        rcsc::Vector2D ball_pos = start_real;
+        double ball_speed = rcsc::ServerParam::i().ballSpeedMax();
+        rcsc::Vector2D ball_vel = end_real - start_real;
+        ball_vel.setLength( ball_speed );
+
+        const double max_length = start_real.dist( end_real );
+        double total_travel = 0.0;
+
+        ball_pos += ball_vel;
+        ball_vel *= rcsc::ServerParam::i().ballDecay();
+        total_travel += ball_vel.r();
+        while ( total_travel < max_length )
+        {
+            mem_dc.DrawCircle( M_data.config().getScreenX( ball_pos.x ),
+                               M_data.config().getScreenY( ball_pos.y ),
+                               1 );
+            ball_pos += ball_vel;
+            ball_vel *= rcsc::ServerParam::i().ballDecay();
+            ball_speed *= rcsc::ServerParam::i().ballDecay();
+            total_travel += ball_speed;
+            if ( ball_speed < 0.05 ) break;
+        }
+    }
+
     // draw distance & angle text
     mem_dc.SetFont( M_data.gdi().getMeasureFont() );
     mem_dc.SetTextForeground( M_data.gdi().getMeasureFontColor() );
