@@ -249,13 +249,29 @@ FieldPainter::drawLines( wxDC & dc ) const
     dc.DrawLine( right_x, bottom_y, left_x, bottom_y );
     dc.DrawLine( left_x, bottom_y, left_x, top_y );
 
-    // center line
-    dc.DrawLine( M_conf.getFieldCenter().x, top_y,
-                 M_conf.getFieldCenter().x, bottom_y );
+    if ( AppConfig::instance().keepaway() )
+    {
+        // keepaway area
+        wxCoord ka_left = M_conf.getScreenX( - AppConfig::instance().keepawayLength() * 0.5 );
+        wxCoord ka_right = M_conf.getScreenX( + AppConfig::instance().keepawayLength() * 0.5 );
+        wxCoord ka_top = M_conf.getScreenY( - AppConfig::instance().keepawayWidth() * 0.5 );
+        wxCoord ka_bottom = M_conf.getScreenY( + AppConfig::instance().keepawayWidth() * 0.5 );
 
-    // center circle
-    wxCoord center_radius = M_conf.scale( AppConfig::CENTER_CIRCLE_R );
-    dc.DrawCircle( M_conf.getFieldCenter(), center_radius );
+        dc.DrawLine( ka_left, ka_top, ka_right, ka_top );
+        dc.DrawLine( ka_right, ka_top, ka_right, ka_bottom );
+        dc.DrawLine( ka_right, ka_bottom, ka_left, ka_bottom );
+        dc.DrawLine( ka_left, ka_bottom, ka_left, ka_top );
+    }
+    else
+    {
+        // center line
+        dc.DrawLine( M_conf.getFieldCenter().x, top_y,
+                     M_conf.getFieldCenter().x, bottom_y );
+
+        // center circle
+        wxCoord center_radius = M_conf.scale( AppConfig::CENTER_CIRCLE_R );
+        dc.DrawCircle( M_conf.getFieldCenter(), center_radius );
+    }
 }
 
 /*-------------------------------------------------------------------*/
