@@ -90,15 +90,13 @@ MainFrame::MainFrame( const wxString & title )
     , M_data( this )
     , M_main_tbar( static_cast< MainToolBar * >( 0 ) )
     , M_field_canvas( static_cast< FieldCanvas * >( 0 ) )
-    , M_view_config_ctrl( new ViewConfigControl( this ) )
+    , M_view_config_ctrl( new ViewConfigControl( this, M_data ) )
     , M_view_config_dlg( static_cast< ViewConfigDialog * >( 0 ) )
     , M_detail_dlg( static_cast< DetailDialog * >( 0 ) )
     , M_image_save_dlg( static_cast< ImageSaveDialog * >( 0 ) )
     , M_debug_message( static_cast< DebugMessageFrame * >( 0 ) )
     , M_logplayer( new LogPlayer( this, M_data ) )
 {
-    SetIcon( wxICON( soccerwindow2_nostr ) );
-
     // set event handlers
     connectEvent();
 
@@ -133,6 +131,7 @@ MainFrame::MainFrame( const wxString & title )
             this->Fit();
         }
     }
+
     if ( AppConfig::instance().hideStatusBar() )
     {
         if ( this->GetStatusBar() )
@@ -141,16 +140,20 @@ MainFrame::MainFrame( const wxString & title )
             this->Fit();
         }
     }
+
     if ( AppConfig::instance().maximize() )
     {
         this->Maximize( true );
     }
+
     if ( AppConfig::instance().fullScreen() )
     {
         this->ShowFullScreen( true );
     }
 
     M_view_config_ctrl->setData( & M_data.getViewConfig() );
+
+    SetIcon( wxICON( soccerwindow2_nostr ) );
 }
 
 /*-------------------------------------------------------------------*/
@@ -544,7 +547,7 @@ MainFrame::saveConfig()
     config_file.SetPath( wxT( "/App" ) );
 
     config_file.Write( wxT( "server-command" ),
-                       wxString( AppConfig::instance().serverCommand().c_str(),
+                       wxString( AppConfig::instance().serverPath().c_str(),
                                  *wxConvCurrent ) );
 
     config_file.Write( wxT( "game-log-dir" ),
@@ -1126,7 +1129,7 @@ MainFrame::restartServer()
         ::wxSleep( 1 ); // sleep 1 sec
     }
 
-    std::string rcssserver = AppConfig::instance().serverCommand();
+    std::string rcssserver = AppConfig::instance().serverPath();
 
     if ( rcssserver.empty() )
     {
