@@ -376,11 +376,11 @@ PlayerPanel::update()
 
     // side, number, type
     temp.Printf( wxT( "%s     %2d" ),
-                 number > 0 ? "   Left" : "   Right",
+                 number > 0 ? wxT( "   Left" ) : wxT( "   Right" ),
                  number > 0 ? number : -number );
     M_number->SetLabel( temp );
 
-    temp.Printf( wxT( "      %d" ), p.type() );
+    temp.Printf( wxT( " %d" ), p.type() );
     M_type->SetLabel( temp );
 
     // pos
