@@ -114,6 +114,9 @@ private:
 
     bool M_ball_auto_trace; //! if true, trace is drawn automatically
     bool M_player_auto_trace; //! if true, trace is drawn automatically
+    long M_auto_trace_start;
+    std::size_t M_auto_trace_period;
+
     bool M_line_trace; //! if true, trace is line, else only trace point is drawn
     long M_ball_trace_start; //!< cycle of ball trace start
     long M_ball_trace_end; //!< cycle of ball trace end
@@ -433,6 +436,28 @@ public:
           return M_player_auto_trace;
       }
 
+    const
+    long & autoTraceStart() const
+      {
+          return M_auto_trace_start;
+      }
+
+    const
+    std::size_t & autoTracePeriod() const
+      {
+          return M_auto_trace_period;
+      }
+
+    void setAutoTraceStart( const long & start )
+      {
+          M_auto_trace_start = start;
+      }
+
+    void setAutoTracePeriod( const std::size_t & period )
+      {
+          M_auto_trace_period = period;
+      }
+
     //! get trace mode
     bool isLineTrace() const
       {
