@@ -48,6 +48,7 @@
 #include <cassert>
 
 #include "app_config.h"
+#include "main_data.h"
 #include "main_frame.h"
 #include "score_board_painter.h"
 
@@ -61,8 +62,10 @@
 /*!
 
 */
-ViewConfigControl::ViewConfigControl( MainFrame * main_frame )
+ViewConfigControl::ViewConfigControl( MainFrame * main_frame,
+                                      const MainData & main_data )
     : M_main_frame( main_frame )
+    , M_main_data( main_data )
     , M_config_data( static_cast< ViewConfig * >( 0 ) )
     , M_config_dlg( static_cast< ViewConfigDialog * >( 0 ) )
     , M_debug_frame( static_cast< DebugMessageFrame * >( 0 ) )
@@ -140,6 +143,11 @@ ViewConfigControl::ViewConfigControl( MainFrame * main_frame )
                            this, &ViewConfigControl::recvToggleBallAutoTrace );
     M_main_frame->connect( SWID_CANVAS_TOGGLE_PLAYER_AUTO_TRACE,
                            this, &ViewConfigControl::recvTogglePlayerAutoTrace );
+    M_main_frame->connect( SWID_SET_AUTO_TRACE_START,
+                           this, &ViewConfigControl::recvSetAutoTraceStart );
+    M_main_frame->connect( SWID_SET_AUTO_TRACE_PERIOD,
+                           this, &ViewConfigControl::recvSetAutoTracePeriod );
+
     M_main_frame->connect( SWID_CANVAS_TOGGLE_TRACE_MODE,
                            this, &ViewConfigControl::recvToggleLineTrace );
     M_main_frame->connect( SWID_SET_BALL_TRACE_START,
@@ -151,6 +159,11 @@ ViewConfigControl::ViewConfigControl( MainFrame * main_frame )
     M_main_frame->connect( SWID_SET_PLAYER_TRACE_END,
                            this, &ViewConfigControl::recvSetPlayerTraceEnd );
 
+    M_main_frame->connect( SWID_CANVAS_BALL_TRACE_SELECT_ALL,
+                           this, &ViewConfigControl::recvBallTraceSelectAll );
+    M_main_frame->connect( SWID_CANVAS_PLAYER_TRACE_SELECT_ALL,
+                           this, &ViewConfigControl::recvPlayerTraceSelectAll );
+
     M_main_frame->connect( SWID_SET_BALL_FUTURE_CYCLE,
                            this, &ViewConfigControl::recvSetBallFutureCycle );
     M_main_frame->connect( SWID_SET_PLAYER_FUTURE_CYCLE,
@@ -919,6 +932,74 @@ ViewConfigControl::recvTogglePlayerAutoTrace( const boost::any * )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+ViewConfigControl::recvSetAutoTraceStart( const boost::any * data )
+{
+    const long * cycle = boost::any_cast< long >( data );
+    if ( ! cycle )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " bad any_cast" << std::endl;
+        return;
+    }
+
+    if ( M_config_data )
+    {
+        M_config_data->setAutoTraceStart( *cycle );
+    }
+
+    if ( M_config_dlg )
+    {
+        M_config_dlg->setAutoTraceStart();
+    }
+
+    if ( ! M_config_data
+         && ( M_config_data->isBallAutoTrace()
+              || M_config_data->isPlayerAutoTrace() )
+         )
+    {
+        M_main_frame->updateView();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigControl::recvSetAutoTracePeriod( const boost::any * data )
+{
+    const std::size_t * period = boost::any_cast< std::size_t >( data );
+    if ( ! period )
+    {
+        std::cerr << __FILE__ << ":" << __LINE__
+                  << " bad any_cast" << std::endl;
+        return;
+    }
+
+    if ( M_config_data )
+    {
+        M_config_data->setAutoTracePeriod( *period );
+    }
+
+    if ( M_config_dlg )
+    {
+        M_config_dlg->setAutoTraceStart();
+    }
+
+    if ( ! M_config_data
+         && ( M_config_data->isBallAutoTrace()
+              || M_config_data->isPlayerAutoTrace() )
+         )
+    {
+        M_main_frame->updateView();
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 ViewConfigControl::recvToggleLineTrace( const boost::any * )
@@ -962,7 +1043,7 @@ ViewConfigControl::recvSetBallTraceStart( const boost::any * data )
     }
 
     if ( ! M_config_data
-         || M_config_data->isShownBallTrace() )
+         && M_config_data->isShownBallTrace() )
     {
         M_main_frame->updateView();
     }
@@ -994,7 +1075,7 @@ ViewConfigControl::recvSetBallTraceEnd( const boost::any * data )
     }
 
     if ( ! M_config_data
-         || M_config_data->isShownBallTrace() )
+         && M_config_data->isShownBallTrace() )
     {
         M_main_frame->updateView();
     }
@@ -1026,7 +1107,7 @@ ViewConfigControl::recvSetPlayerTraceStart( const boost::any * data )
     }
 
     if ( ! M_config_data
-         || M_config_data->isShownPlayerTrace() )
+         && M_config_data->isShownPlayerTrace() )
     {
         M_main_frame->updateView();
     }
@@ -1058,7 +1139,7 @@ ViewConfigControl::recvSetPlayerTraceEnd( const boost::any * data )
     }
 
     if ( ! M_config_data
-         || M_config_data->isShownPlayerTrace() )
+         && M_config_data->isShownPlayerTrace() )
     {
         M_main_frame->updateView();
     }
@@ -1067,6 +1148,56 @@ ViewConfigControl::recvSetPlayerTraceEnd( const boost::any * data )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+ViewConfigControl::recvBallTraceSelectAll( const boost::any * )
+{
+    if ( M_config_data )
+    {
+        const std::vector< MonitorViewPtr > & view
+            = M_main_data.getViewHolder().getMonitorViewCont();
+        if ( ! view.empty() )
+        {
+            M_config_data->setBallTraceStart( view.front()->cycle() );
+            M_config_data->setBallTraceEnd( view.back()->cycle() );
+            if ( M_config_dlg )
+            {
+                M_config_dlg->setBallTraceStart();
+                M_config_dlg->setBallTraceEnd();
+            }
+            M_main_frame->updateView();
+        }
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigControl::recvPlayerTraceSelectAll( const boost::any * )
+{
+    if ( M_config_data )
+    {
+        const std::vector< MonitorViewPtr > & view
+            = M_main_data.getViewHolder().getMonitorViewCont();
+        if ( ! view.empty() )
+        {
+            M_config_data->setPlayerTraceStart( view.front()->cycle() );
+            M_config_data->setPlayerTraceEnd( view.back()->cycle() );
+            if ( M_config_dlg )
+            {
+                M_config_dlg->setPlayerTraceStart();
+                M_config_dlg->setPlayerTraceEnd();
+            }
+            M_main_frame->updateView();
+        }
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 ViewConfigControl::recvSetBallFutureCycle( const boost::any * data )
