@@ -85,6 +85,12 @@ ViewConfigDialog::ViewConfigDialog( wxWindow * parent,
     , M_player_trace_end( new wxTextCtrl( this, SWID_TEXTBOX_PLAYER_TRACE_END,
                                           wxT( "0" ),
                                           wxDefaultPosition, wxSize( 40, -1 ) ) )
+    , M_auto_trace_start( new wxTextCtrl( this, SWID_TEXTBOX_AUTO_TRACE_START,
+                                          wxT( "-10" ),
+                                          wxDefaultPosition, wxSize( 40, -1 ) ) )
+    , M_auto_trace_period( new wxTextCtrl( this, SWID_TEXTBOX_AUTO_TRACE_PERIOD,
+                                           wxT( "20" ),
+                                           wxDefaultPosition, wxSize( 40, -1 ) ) )
     , M_ball_future( new wxSpinCtrl( this, SWID_TEXTBOX_BALL_FUTURE_CYCLE ) )
     , M_player_future( new wxSpinCtrl( this, SWID_TEXTBOX_PLAYER_FUTURE_CYCLE ) )
     , M_canvas_width_text( static_cast< wxTextCtrl * >( 0 ) )
@@ -605,7 +611,12 @@ ViewConfigDialog::createTraceControls()
 {
     wxStaticBox * sbox = new wxStaticBox( this, -1,
                                           wxT( "Trace" ) );
-    wxStaticBoxSizer * sizer = new wxStaticBoxSizer( sbox, wxHORIZONTAL );
+    wxStaticBoxSizer * main_sizer = new wxStaticBoxSizer( sbox, wxVERTICAL );
+
+    int text_all_width, text_all_height;
+    this->GetTextExtent( wxT( "All" ), &text_all_width, &text_all_height );
+
+    wxBoxSizer * sizer = new wxBoxSizer( wxHORIZONTAL );
     {
         wxStaticBox * bsbox = new wxStaticBox( this, -1,
                                                wxT( "Ball" ) );
@@ -616,6 +627,12 @@ ViewConfigDialog::createTraceControls()
                      0, wxLEFT | wxRIGHT, 1 );
         bsizer->Add( M_ball_trace_end,
                      0, 0, 0 );
+        bsizer->Add( new wxButton( this, SWID_CANVAS_BALL_TRACE_SELECT_ALL,
+                                   wxT( "All" ),
+                                   wxDefaultPosition,
+                                   wxSize( text_all_width + 12, -1 ) ),
+                     0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 2 );
+
         M_ball_trace_cb = new wxCheckBox( this,
                                           SWID_CANVAS_TOGGLE_BALL_AUTO_TRACE,
                                           wxT( "Auto" ) );
@@ -635,6 +652,12 @@ ViewConfigDialog::createTraceControls()
                      0, wxLEFT | wxRIGHT, 1 );
         psizer->Add( M_player_trace_end,
                      0, 0, 0 );
+        psizer->Add( new wxButton( this, SWID_CANVAS_PLAYER_TRACE_SELECT_ALL,
+                                   wxT( "All" ),
+                                   wxDefaultPosition,
+                                   wxSize( text_all_width + 12, -1 ) ),
+                     0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 2 );
+
         M_player_trace_cb =  new wxCheckBox( this,
                                              SWID_CANVAS_TOGGLE_PLAYER_AUTO_TRACE,
                                              wxT( "Auto" ) );
@@ -645,14 +668,36 @@ ViewConfigDialog::createTraceControls()
         sizer->Add( psizer,
                     0, wxLEFT | wxRIGHT, 2 );
     }
-    sizer->Add( 6, 0 );
+
+    main_sizer->Add( sizer );
+    main_sizer->Add( 6, 0 );
+
+    wxBoxSizer * sizer2 = new wxBoxSizer( wxHORIZONTAL );
     {
-        sizer->Add( new wxButton( this, SWID_CANVAS_TOGGLE_TRACE_MODE,
-                                  wxT( "Line/Point" ) ),
-                    0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 2 );
+        wxStaticBox * trace_box = new wxStaticBox( this, -1, wxT( "Auto Trace Period" ) );
+        wxStaticBoxSizer * tsizer = new wxStaticBoxSizer( trace_box, wxHORIZONTAL );
+        tsizer->Add( new wxStaticText( this, -1, wxT( "Start:" ) ),
+                     0, wxLEFT | wxRIGHT | wxALIGN_CENTER_VERTICAL, 1 );
+        tsizer->Add( M_auto_trace_start,
+                     0, 0, 0 );
+        tsizer->Add( 2, 0 );
+        tsizer->Add( new wxStaticText( this, -1, wxT( "Period:" ) ),
+                     0, wxLEFT | wxRIGHT | wxALIGN_CENTER_VERTICAL, 1 );
+        tsizer->Add( M_auto_trace_period,
+                     0, 0, 0 );
+
+        sizer2->Add( tsizer );
+    }
+    sizer2->Add( 12, 0 );
+    {
+        sizer2->Add( new wxButton( this, SWID_CANVAS_TOGGLE_TRACE_MODE,
+                                   wxT( "Line/Point" ) ),
+                     0, wxALIGN_CENTER_VERTICAL | wxCENTER, 2 );
     }
 
-    return sizer;
+    main_sizer->Add( sizer2 );
+
+    return main_sizer;
 }
 
 /*-------------------------------------------------------------------*/
@@ -736,6 +781,11 @@ ViewConfigDialog::connectEvents()
     Connect( SWID_TEXTBOX_PLAYER_TRACE_END, wxEVT_COMMAND_TEXT_UPDATED,
              wxTextEventHandler( ViewConfigDialog::handlePlayerTraceEnd ) );
 
+    Connect( SWID_TEXTBOX_AUTO_TRACE_START, wxEVT_COMMAND_TEXT_UPDATED,
+             wxTextEventHandler( ViewConfigDialog::handleAutoTraceStart ) );
+    Connect( SWID_TEXTBOX_AUTO_TRACE_PERIOD, wxEVT_COMMAND_TEXT_UPDATED,
+             wxTextEventHandler( ViewConfigDialog::handleAutoTracePeriod ) );
+
     Connect( SWID_TEXTBOX_BALL_FUTURE_CYCLE, wxEVT_COMMAND_SPINCTRL_UPDATED,
              wxSpinEventHandler( ViewConfigDialog::handleBallFutureCycle ) );
     Connect( SWID_TEXTBOX_PLAYER_FUTURE_CYCLE, wxEVT_COMMAND_SPINCTRL_UPDATED,
@@ -926,6 +976,42 @@ ViewConfigDialog::handlePlayerTraceEnd( wxCommandEvent & WXUNUSED(event) )
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+ViewConfigDialog::handleAutoTraceStart( wxCommandEvent & WXUNUSED(event) )
+{
+    wxString val = M_auto_trace_start->GetValue();
+    unsigned long ucycle = 0;
+    if ( ! val.ToULong( &ucycle ) )
+    {
+        return;
+    }
+
+    M_main_frame->handle( EventMessage( SWID_SET_AUTO_TRACE_START,
+                                        static_cast< long >( ucycle ) ) );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigDialog::handleAutoTracePeriod( wxCommandEvent & WXUNUSED(event) )
+{
+    wxString val = M_auto_trace_period->GetValue();
+    unsigned long ucycle = 0;
+    if ( ! val.ToULong( &ucycle ) )
+    {
+        return;
+    }
+
+    M_main_frame->handle( EventMessage( SWID_SET_AUTO_TRACE_PERIOD,
+                                        static_cast< std::size_t >( ucycle ) ) );
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 ViewConfigDialog::handleBallFutureCycle( wxSpinEvent & WXUNUSED( event ) )
@@ -1177,6 +1263,10 @@ ViewConfigDialog::setBallAutoTrace()
     M_ball_trace_cb->SetValue( M_config.isBallAutoTrace() );
 }
 
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
 void
 ViewConfigDialog::setPlayerAutoTrace()
 {
@@ -1186,6 +1276,26 @@ ViewConfigDialog::setPlayerAutoTrace()
 /*-------------------------------------------------------------------*/
 /*!
 
+*/
+void
+ViewConfigDialog::setAutoTraceStart()
+{
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+ViewConfigDialog::setAutoTracePeriod()
+{
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
 */
 void
 ViewConfigDialog::setLineTrace()
