@@ -430,6 +430,11 @@ ViewHolder::getIndexOf( const long & cycle ) const
 
     if ( first == M_monitor_view_cont.end() )
     {
+        if ( cycle > 0
+             && ! M_monitor_view_cont.empty() )
+        {
+            return M_monitor_view_cont.size() - 1;
+        }
         return 0;
     }
 
